import { APIRequest } from '../utils/APIRequest';
import { RequestOpts, LimitationParamsWithAuthenticationCheck } from '../typings';
import { IReportHashtagOpts } from '../typings/api/hashtags';
/**
 * HashtagsAPI - Prodivdes methods to interface with hashtag API endpoints
 */
declare class HashtagsAPI extends APIRequest {
    constructor(opts: RequestOpts);
    /**
     * `GET /api/hashtags/trending` - promises to retrieve the trending hashtags
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    getTrendingHashtags(authenticatedRequest?: boolean): Promise<any>;
    /**
     * `GET /api/hashtags/suggested` - promises to retrieve the suggested hashtags
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    getSuggestedHashtags(authenticatedRequest?: boolean): Promise<any>;
    /**
     * `GET /api/hashtags/search` - promises to search for hashtags
     * @param {string} query - the search query
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    getHashtagsWithQuery(query: string, authenticatedRequest?: boolean): Promise<any>;
    /**
     * `GET /api/hashtags/:name` - promises to get a hashtag by name
     * @param {string} name - the name of the hashtag
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    getHashtagWithName(name: string, authenticatedRequest?: boolean): Promise<any>;
    /**
     * `POST /api/hashtags/:name/report` - promises to report a hashtag
     * @param {IReportHashtagOpts} opts - options for hashtag reporting
     */
    reportHashtagWithName(opts: IReportHashtagOpts): Promise<any>;
    /**
     * `GET /api/hashtags/:name/posts` - promises to get a list of posts that contain the specified hashtag
     * @param {string} name - the name of the hashtag
     * @param {LimitationParamsWithAuthenticationCheck} - limitation options
     */
    getPostsForHashtagWithName(name: string, opts: LimitationParamsWithAuthenticationCheck): Promise<any>;
}
export { HashtagsAPI };
