"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * HashtagsAPI - Prodivdes methods to interface with hashtag API endpoints
 */
var HashtagsAPI = /** @class */ (function (_super) {
    tslib_1.__extends(HashtagsAPI, _super);
    function HashtagsAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `GET /api/hashtags/trending` - promises to retrieve the trending hashtags
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    HashtagsAPI.prototype.getTrendingHashtags = function (authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('trending');
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/hashtags/suggested` - promises to retrieve the suggested hashtags
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    HashtagsAPI.prototype.getSuggestedHashtags = function (authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('suggested');
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/hashtags/search` - promises to search for hashtags
     * @param {string} query - the search query
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    HashtagsAPI.prototype.getHashtagsWithQuery = function (query, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('search');
                this._params.query = query;
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/hashtags/:name` - promises to get a hashtag by name
     * @param {string} name - the name of the hashtag
     * @param {boolean} authenticatedRequest - specifies whether the current session is authenticated
     */
    HashtagsAPI.prototype.getHashtagWithName = function (name, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name));
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/hashtags/:name/report` - promises to report a hashtag
     * @param {IReportHashtagOpts} opts - options for hashtag reporting
     */
    HashtagsAPI.prototype.reportHashtagWithName = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                payload = {
                    category_id: opts.moderationCategoryId.toString()
                };
                if (opts.description) {
                    payload.description = opts.description;
                }
                this._paths.push(encodeURIComponent(opts.hashtagName), 'report');
                return [2 /*return*/, this.post(payload)];
            });
        });
    };
    /**
     * `GET /api/hashtags/:name/posts` - promises to get a list of posts that contain the specified hashtag
     * @param {string} name - the name of the hashtag
     * @param {LimitationParamsWithAuthenticationCheck} - limitation options
     */
    HashtagsAPI.prototype.getPostsForHashtagWithName = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'posts');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                return [2 /*return*/, this.get()];
            });
        });
    };
    return HashtagsAPI;
}(APIRequest_1.APIRequest));
exports.HashtagsAPI = HashtagsAPI;
