"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * NotificationsAPI - Provides methods to interact with the Notifications API
 */
var NotificationsAPI = /** @class */ (function (_super) {
    tslib_1.__extends(NotificationsAPI, _super);
    function NotificationsAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `GET /api/notifications/` - promises to retrieve the user's notifications
     * @param {IGetNotificationOpts} opts - The limitation rules
     */
    NotificationsAPI.prototype.getNotifications = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.types && opts.types.length) {
                    this._params.types = opts.types.join(',');
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/notifications/unread/count` - promises to get the count of the user's unread notifications
     * @param {IGetNotificationOpts} opts - The limitation rules
     */
    NotificationsAPI.prototype.getUnreadNotificationsCount = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('unread', 'count');
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.types && opts.types.length) {
                    this._params.types = opts.types.join(',');
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/notifications/read/` - promises to mark notifications as read
     * @param {IGetNotificationOpts} opts - The limitation rules
     */
    NotificationsAPI.prototype.readNotifications = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('read');
                body = {};
                if (opts.maxId) {
                    body.max_id = opts.maxId;
                }
                if (opts.types && opts.types.length) {
                    body.types = opts.types.join(',');
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    /**
     * `DELETE /api/notifications/` - promises to delete all notifications
     */
    NotificationsAPI.prototype.deleteNotifications = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `DELETE /api/notifications/:id/` - promises to delete a notification
     * @param {number} id - The ID of the notification
     */
    NotificationsAPI.prototype.deleteNotification = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `GET /api/notifications/:id/` - promises to get a notification
     * @param {number} id - The ID of the notification
     */
    NotificationsAPI.prototype.getNotification = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/notifications/:id/` - promises to mark a notification as read
     * @param {number} id - The ID of the notification
     */
    NotificationsAPI.prototype.readNotification = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.post({})];
            });
        });
    };
    return NotificationsAPI;
}(APIRequest_1.APIRequest));
exports.NotificationsAPI = NotificationsAPI;
